@@ -55,7 +55,8 @@ def create_hexagon(center_lat, center_lon, radius, angle=0.):
 
 
 class HexagonControlWidget(QtWidgets.QWidget, ui.Ui_HexagonDockWidget):
-    """This class implements the remote sensing functionality as dockable widget.
+    """
+    This class implements the remote sensing functionality as dockable widget.
     """
 
     def __init__(self, parent=None, view=None):
@@ -67,12 +68,23 @@ class HexagonControlWidget(QtWidgets.QWidget, ui.Ui_HexagonDockWidget):
         super(HexagonControlWidget, self).__init__(parent)
         self.setupUi(self)
         self.view = view
+        if self.view:
+            self.view.tableWayPoints.selectionModel().selectionChanged.connect(self.on_selection_changed)
+            self.on_selection_changed(None)
 
         self.dsbHexgaonRadius.setValue(200)
 
         self.pbAddHexagon.clicked.connect(self._add_hexagon)
         self.pbRemoveHexagon.clicked.connect(self._remove_hexagon)
 
+    def on_selection_changed(self, index):
+        """
+        Disables add and remove when multiple rows are selected
+        """
+        enable = len(self.view.tableWayPoints.selectionModel().selectedRows()) <= 1
+        self.pbAddHexagon.setEnabled(enable)
+        self.pbRemoveHexagon.setEnabled(enable)
+
     def _get_parameters(self):
         return {
             "center_lon": self.dsbHexagonLongitude.value(),
