@@ -13,7 +13,7 @@
 
     :copyright: Copyright 2008-2014 Deutsches Zentrum fuer Luft- und Raumfahrt e.V.
     :copyright: Copyright 2011-2014 Marc Rautenhaus (mr)
-    :copyright: Copyright 2016-2020 by the mss team, see AUTHORS.
+    :copyright: Copyright 2016-2021 by the mss team, see AUTHORS.
     :license: APACHE-2.0, see LICENSE for details.
 
     Licensed under the Apache License, Version 2.0 (the "License");
@@ -68,20 +68,21 @@ import fs
 from mslib import __version__
 from mslib.msui.mss_qt import ui_mainwindow as ui
 from mslib.msui.mss_qt import ui_about_dialog as ui_ab
+from mslib.msui.mss_qt import ui_shortcuts as ui_sh
 from mslib.msui import flighttrack as ft
 from mslib.msui import tableview
 from mslib.msui import topview
 from mslib.msui import sideview
+from mslib.msui import linearview
 from mslib.msui import editor
 from mslib.msui import constants
 from mslib.msui import wms_control
 from mslib.msui import mscolab
 from mslib.utils import config_loader, setup_logging
-from mslib.msui import MissionSupportSystemDefaultConfig as mss_default
 from mslib.plugins.io.csv import load_from_csv, save_to_csv
 from mslib.msui.icons import icons, python_powered
-from mslib.msui.mss_qt import QtGui, QtCore, QtWidgets, get_open_filename, get_save_filename
-
+from mslib.msui.mss_qt import get_open_filename, get_save_filename
+from PyQt5 import QtGui, QtCore, QtWidgets
 
 # Add config path to PYTHONPATH so plugins located there may be found
 sys.path.append(constants.MSS_CONFIG_PATH)
@@ -105,11 +106,11 @@ class QActiveViewsListWidgetItem(QtWidgets.QListWidgetItem):
         """Add ID number to the title of the corresponding view window.
         """
         QActiveViewsListWidgetItem.opened_views += 1
-        view_name = "({:d}) {}".format(QActiveViewsListWidgetItem.opened_views, view_window.name)
+        view_name = f"({QActiveViewsListWidgetItem.opened_views:d}) {view_window.name}"
         super(QActiveViewsListWidgetItem, self).__init__(view_name, parent, type)
 
-        view_window.setWindowTitle("({:d}) {}".format(
-            QActiveViewsListWidgetItem.opened_views, view_window.windowTitle()))
+        view_window.setWindowTitle(f"({QActiveViewsListWidgetItem.opened_views:d}) {view_window.windowTitle()} - "
+                                   f"{view_window.waypoints_model.name}")
         view_window.setIdentifier(view_name)
         self.window = view_window
         self.parent = parent
@@ -152,6 +153,59 @@ class QFlightTrackListWidgetItem(QtWidgets.QListWidgetItem):
         self.flighttrack_model = flighttrack_model
 
 
+class MSS_ShortcutsDialog(QtWidgets.QDialog, ui_sh.Ui_ShortcutsDialog):
+    """
+    Dialog showing shortcuts for all currently open windows
+    """
+
+    def __init__(self):
+        super(MSS_ShortcutsDialog, self).__init__(QtWidgets.QApplication.activeWindow())
+        self.setupUi(self)
+        self.current_shortcuts = self.get_shortcuts()
+        self.fill_list()
+
+    def fill_list(self):
+        """
+        Fills the treeWidget with all relevant windows as top level items and their shortcuts as children
+        """
+        for widget in self.current_shortcuts:
+            name = widget.window().windowTitle()
+            if len(name) == 0 or widget.window().isHidden():
+                continue
+            header = QtWidgets.QTreeWidgetItem(self.treeWidget)
+            header.setText(0, name)
+            if widget.window() == self.parent():
+                header.setExpanded(True)
+                header.setSelected(True)
+                self.treeWidget.setCurrentItem(header)
+            for description, shortcut in self.current_shortcuts[widget].items():
+                item = QtWidgets.QTreeWidgetItem(header)
+                item.setText(0, f"{description}: {shortcut}")
+                header.addChild(item)
+
+    def get_shortcuts(self):
+        """
+        Iterates through all top level widgets and puts their shortcuts in a dictionary
+        """
+        shortcuts = {}
+        for qobject in QtWidgets.QApplication.topLevelWidgets():
+            actions = [(qobject.window(), "Show Current Shortcuts", "Alt+S")]
+            actions.extend([
+                (action.parent().window(), action.toolTip(), ",".join(
+                    [shortcut.toString() for shortcut in action.shortcuts()]))
+                for action in qobject.findChildren(QtWidgets.QAction) if len(action.shortcuts()) > 0])
+            actions.extend([(shortcut.parentWidget().window(), shortcut.whatsThis(), shortcut.key().toString())
+                            for shortcut in qobject.findChildren(QtWidgets.QShortcut)])
+            actions.extend([(button.window(), button.toolTip(), button.shortcut().toString())
+                            for button in qobject.findChildren(QtWidgets.QAbstractButton) if button.shortcut()])
+            for item in actions:
+                if item[0] not in shortcuts:
+                    shortcuts[item[0]] = {}
+                shortcuts[item[0]][item[1].replace(f"({item[2]})", "").strip()] = item[2]
+
+        return shortcuts
+
+
 class MSS_AboutDialog(QtWidgets.QDialog, ui_ab.Ui_AboutMSUIDialog):
     """Dialog showing information about MSUI. Most of the displayed text is
        defined in the QtDesigner file.
@@ -165,8 +219,8 @@ class MSS_AboutDialog(QtWidgets.QDialog, ui_ab.Ui_AboutMSUIDialog):
         super(MSS_AboutDialog, self).__init__(parent)
         self.setupUi(self)
         self.lblVersion.setText("Version: {}".format(__version__))
-        changes = f"https://github.com/Open-MSS/MSS/issues?q=is%3Aclosed+milestone%3A{__version__[:-1]}"
-        self.lblChanges.setText(f'<a href="{changes}">New Features and Changes</a>')
+        self.milestone_url = f'https://github.com/Open-MSS/MSS/issues?q=is%3Aclosed+milestone%3A{__version__[:-1]}'
+        self.lblChanges.setText(f'<a href="{self.milestone_url}">New Features and Changes</a>')
         blub = QtGui.QPixmap(python_powered())
         self.lblPython.setPixmap(blub)
 
@@ -186,14 +240,14 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         # instead of the default Icon of python/pythonw
         try:
             import ctypes
-            myappid = "mss.mss_pyui.{}".format(__version__)  # arbitrary string
+            myappid = f"mss.mss_pyui.{__version__}"  # arbitrary string
             ctypes.windll.shell32.SetCurrentProcessExplicitAppUserModelID(myappid)
         except (ImportError, AttributeError) as error:
             logging.debug("AttributeError, ImportError Exception %s", error)
         # Reference to the flight track that is currently displayed in the
         # views.
         self.active_flight_track = None
-        self.last_save_directory = config_loader(dataset="data_dir", default=mss_default.data_dir)
+        self.last_save_directory = config_loader(dataset="data_dir")
         self.mscolab_window = None
         self.config_editor = None
 
@@ -212,6 +266,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         self.actionTopView.triggered.connect(self.create_new_view)
         self.actionSideView.triggered.connect(self.create_new_view)
         self.actionTableView.triggered.connect(self.create_new_view)
+        self.actionLinearView.triggered.connect(self.create_new_view)
 
         # mscolab menu
         self.actionMscolabProjects.triggered.connect(self.activate_mscolab_window)
@@ -219,6 +274,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         # Help menu.
         self.actionOnlineHelp.triggered.connect(self.show_online_help)
         self.actionAboutMSUI.triggered.connect(self.show_about_dialog)
+        self.actionShortcuts.triggered.connect(self.show_shortcuts)
+        self.actionShortcuts.setShortcutContext(QtCore.Qt.ApplicationShortcut)
 
         # Config
         self.actionLoadConfigurationFile.triggered.connect(self.load_config_file)
@@ -230,19 +287,17 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         # Views.
         self.listViews.itemActivated.connect(self.activate_sub_window)
 
-        self.add_import_filter("CSV", "csv", load_from_csv, pickertag="filepicker_flightrack")
-        self.add_export_filter("CSV", "csv", save_to_csv, pickertag="filepicker_flightrack")
+        self.add_import_filter("CSV", "csv", load_from_csv, pickertag="filepicker_default")
+        self.add_export_filter("CSV", "csv", save_to_csv, pickertag="filepicker_default")
 
         self._imported_plugins, self._exported_plugins = {}, {}
         self.add_plugins()
 
-        preload_urls = config_loader(dataset="WMS_preload", default=[])
+        preload_urls = config_loader(dataset="WMS_preload")
         self.preload_wms(preload_urls)
 
         # Status Bar
         self.labelStatusbar.setText(self.status())
-        # Instantiates object of MSS Tableview window helping in force close it.
-        self.tv_window = None
 
     @staticmethod
     def preload_wms(urls):
@@ -260,7 +315,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             pdlg.setValue(i)
             QtWidgets.QApplication.processEvents()
             # initialize login cache from config file, but do not overwrite existing keys
-            for key, value in config_loader(dataset="WMS_login", default={}).items():
+            for key, value in config_loader(dataset="WMS_login").items():
                 if key not in constants.WMS_LOGIN_CACHE:
                     constants.WMS_LOGIN_CACHE[key] = value
             username, password = constants.WMS_LOGIN_CACHE.get(base_url, (None, None))
@@ -269,7 +324,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 request = requests.get(base_url)
                 if pdlg.wasCanceled():
                     break
-                wms = wms_control.MSSWebMapService(request.url, version='1.1.1',
+
+                wms = wms_control.MSSWebMapService(request.url, version=None,
                                                    username=username, password=password)
                 wms_control.WMS_SERVICE_CACHE[wms.url] = wms
                 logging.info("Stored WMS info for '%s'", wms.url)
@@ -282,9 +338,9 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
 
     def add_plugins(self):
         picker_default = config_loader(
-            dataset="filepicker_default", default=mss_default.filepicker_default)
+            dataset="filepicker_default")
 
-        self._imported_plugins = config_loader(dataset="import_plugins", default={})
+        self._imported_plugins = config_loader(dataset="import_plugins")
         for name in self._imported_plugins:
             extension, module, function = self._imported_plugins[name][:3]
             picker_type = picker_default
@@ -297,8 +353,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 logging.error("Error on import: %s: %s", type(ex), ex)
                 QtWidgets.QMessageBox.critical(
                     self, self.tr("file io plugin error import plugins"),
-                    self.tr("ERROR: Configuration\n\n{}\n\nthrows {} error:\n{}".format(
-                        self._imported_plugins, type(ex), ex)))
+                    self.tr(f"ERROR: Configuration\n\n{self._imported_plugins}\n\nthrows {type(ex)} error:\n{ex}"))
                 continue
             try:
                 self.add_import_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
@@ -307,11 +362,11 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 logging.error("Error on installing plugin: %s: %s", type(ex), ex)
                 QtWidgets.QMessageBox.critical(
                     self, self.tr("file io plugin error import plugins"),
-                    self.tr("ERROR: Configuration\n\n{}\n\nthrows {} error:\n{}".format(
-                        self._imported_plugins, type(ex), ex)))
+                    self.tr(f"ERROR: Configuration\n\n{self._imported_plugins}\n\nthrows {type(ex)} error:\n{ex}"))
+
                 continue
 
-        self._exported_plugins = config_loader(dataset="export_plugins", default={})
+        self._exported_plugins = config_loader(dataset="export_plugins")
         for name in self._exported_plugins:
             extension, module, function = self._exported_plugins[name][:3]
             picker_type = picker_default
@@ -324,8 +379,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 logging.error("Error on import: %s: %s", type(ex), ex)
                 QtWidgets.QMessageBox.critical(
                     self, self.tr("file io plugin error import plugins"),
-                    self.tr("ERROR: Configuration\n\n{}\n\nthrows {} error:\n{}".format(
-                        self._exported_plugins, type(ex), ex)))
+                    self.tr(f"ERROR: Configuration\n\n{self._exported_plugins,}\n\nthrows {type(ex)} error:\n{ex}"))
                 continue
             try:
                 self.add_export_filter(name, extension, getattr(imported_module, function), pickertype=picker_type)
@@ -334,8 +388,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 logging.error("Error on installing plugin: %s: %s", type(ex), ex)
                 QtWidgets.QMessageBox.critical(
                     self, self.tr("file io plugin error"),
-                    self.tr("ERROR: Configuration for export {} plugins\n\n{}\n\nthrows error:\n{}".format(
-                        self._exported_plugins, type(ex), ex)))
+                    self.tr(f"ERROR: Configuration for export {self._exported_plugins} plugins\n\n{type(ex)}\n"
+                            f"\nthrows error:\n{ex}"))
                 continue
 
     def remove_plugins(self):
@@ -358,7 +412,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
     def add_import_filter(self, name, extension, function, pickertag=None, pickertype=None):
         full_name = "actionImportFlightTrack" + clean_string(name)
         if hasattr(self, full_name):
-            raise ValueError("'{}' has already been set!".format(full_name))
+            raise ValueError(f"'{full_name}' has already been set!")
 
         action = QtWidgets.QAction(self)
         action.setObjectName(full_name)
@@ -370,6 +424,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 self, "Import Flight Track", self.last_save_directory,
                 "All Files (*." + extension + ")", pickertype=pickertype)
             if filename is not None:
+                self.last_save_directory = fs.path.dirname(filename)
                 try:
                     ft_name, new_waypoints = function(filename)
                 # wildcard exception to be resilient against error introduced by user code
@@ -377,7 +432,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                     logging.error("file io plugin error: %s %s", type(ex), ex)
                     QtWidgets.QMessageBox.critical(
                         self, self.tr("file io plugin error"),
-                        self.tr("ERROR: {} {}".format(type(ex), ex)))
+                        self.tr(f"ERROR: {type(ex)} {ex}"))
                 else:
                     if not ft_name:
                         ft_name = filename
@@ -395,7 +450,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
     def add_export_filter(self, name, extension, function, pickertag=None, pickertype=None):
         full_name = "actionExportFlightTrack" + clean_string(name)
         if hasattr(self, full_name):
-            raise ValueError("'{}' has already been set!".format(full_name))
+            raise ValueError(f"'{full_name}' has already been set!")
 
         action = QtWidgets.QAction(self)
         action.setObjectName(full_name)
@@ -408,6 +463,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 self, "Export Flight Track", default_filename,
                 name + " (*." + extension + ")", pickertype=pickertype)
             if filename is not None:
+                self.last_save_directory = fs.path.dirname(filename)
                 try:
                     function(filename, self.active_flight_track.name, self.active_flight_track.waypoints)
                 # wildcard exception to be resilient against error introduced by user code
@@ -415,7 +471,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                     logging.error("file io plugin error: %s %s", type(ex), ex)
                     QtWidgets.QMessageBox.critical(
                         self, self.tr("file io plugin error"),
-                        self.tr("ERROR: {} {}".format(type(ex), ex)))
+                        self.tr(f"ERROR: {type(ex)} {ex}"))
 
         setattr(self, full_name, types.MethodType(save_function_wrapper, self))
         action.triggered.connect(getattr(self, full_name))
@@ -435,6 +491,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         if ret == QtWidgets.QMessageBox.Yes:
             # Table View stick around after MainWindow closes - maybe some dangling reference?
             # This removes them for sure!
+            while self.listViews.count() > 0:
+                self.listViews.item(0).window.handle_force_close()
             self.listViews.clear()
             self.listFlightTracks.clear()
             # cleanup mscolab window
@@ -442,11 +500,6 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 self.mscolab_window.close()
             if self.config_editor is not None:
                 self.config_editor.close()
-            # tv = tableview ; it is an object of MSS Tableview window. Used for force closing it.
-            if self.tv_window is not None:
-                if self.tv_window.exists():  # checks whether or not tableview window has closed before
-                    self.tv_window.handle_force_close()     # enters condition when tableview window is not closed.
-                    self.tv_window = None
             event.accept()
         else:
             event.ignore()
@@ -456,7 +509,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
            a new instance of the view and adds a QActiveViewsListWidgetItem to
            the list of open views (self.listViews).
         """
-        layout = config_loader(dataset="layout", default=mss_default.layout)
+        layout = config_loader(dataset="layout")
         view_window = None
         if self.sender() == self.actionTopView:
             # Top view.
@@ -474,7 +527,12 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             # Table view.
             view_window = tableview.MSSTableViewWindow(model=self.active_flight_track)
             view_window.centralwidget.resize(layout['tableview'][0], layout['tableview'][1])
-            self.tv_window = view_window
+        elif self.sender() == self.actionLinearView:
+            # Linear view.
+            view_window = linearview.MSSLinearViewWindow(model=self.active_flight_track)
+            view_window.mpl.resize(layout['linearview'][0], layout['linearview'][1])
+            if layout["immutable"]:
+                view_window.mpl.setFixedSize(layout['linearview'][0], layout['linearview'][1])
         if view_window is not None:
             # Make sure view window will be deleted after being closed, not
             # just hidden (cf. Chapter 5 in PyQt4).
@@ -527,9 +585,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         """
         if template is None:
             template = []
-            waypoints = config_loader(dataset="new_flighttrack_template", default=mss_default.new_flighttrack_template)
-            default_flightlevel = config_loader(dataset="new_flighttrack_flightlevel",
-                                                default=mss_default.new_flighttrack_flightlevel)
+            waypoints = config_loader(dataset="new_flighttrack_template")
+            default_flightlevel = config_loader(dataset="new_flighttrack_flightlevel")
             for wp in waypoints:
                 template.append(ft.Waypoint(flightlevel=default_flightlevel, location=wp))
             if len(template) < 2:
@@ -544,7 +601,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             # Create a new flight track from the waypoints template.
             self.new_flight_track_counter += 1
             waypoints_model = ft.WaypointsTableModel(
-                name="new flight track ({:d})".format(self.new_flight_track_counter))
+                name=f"new flight track ({self.new_flight_track_counter:d})")
             # Make a copy of the template. Otherwise all new flight tracks would
             # use the same data structure in memory.
             template_copy = copy.deepcopy(template)
@@ -557,6 +614,8 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         self.activate_flight_track(listitem)
 
     def restart_application(self):
+        while self.listViews.count() > 0:
+            self.listViews.item(0).window.handle_force_close()
         self.listViews.clear()
         self.remove_plugins()
         self.add_plugins()
@@ -571,8 +630,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
             QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No, QtWidgets.QMessageBox.No)
         if ret == QtWidgets.QMessageBox.Yes:
             filename = get_open_filename(
-                self, "Open Config file", constants.MSS_CONFIG_PATH, "Config Files (*.json)",
-                pickertag="filepicker_config")
+                self, "Open Config file", constants.MSS_CONFIG_PATH, "Config Files (*.json)")
             if filename is not None:
                 constants.CACHED_CONFIG_FILE = filename
                 self.restart_application()
@@ -598,19 +656,20 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         """
         filename = get_open_filename(
             self, "Open Flight Track", self.last_save_directory, "Flight Track Files (*.ftml)",
-            pickertag="filepicker_flightrack")
+            pickertag="filepicker_default")
         if filename is not None:
+            self.last_save_directory = fs.path.dirname(filename)
             try:
                 if filename.endswith('.ftml'):
                     self.create_new_flight_track(filename=filename)
                 else:
                     QtWidgets.QMessageBox.warning(self, "Open flight track",
-                                                  "No supported file extension recognized!\n{:}".format(filename))
+                                                  f"No supported file extension recognized!\n{filename:}")
 
             except (SyntaxError, OSError, IOError) as ex:
                 QtWidgets.QMessageBox.critical(
                     self, self.tr("Problem while opening flight track FTML:"),
-                    self.tr("ERROR: {} {}".format(type(ex), ex)))
+                    self.tr(f"ERROR: {type(ex)} {ex}"))
 
     def activate_selected_flight_track(self):
         item = self.listFlightTracks.currentItem()
@@ -645,7 +704,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         filename = self.active_flight_track.get_filename()
         if filename and filename.endswith('.ftml'):
             sel = QtWidgets.QMessageBox.question(self, "Save flight track",
-                                                 "Saving flight track to '{:s}'. Continue?".format(filename),
+                                                 f"Saving flight track to '{filename:s}'. Continue?",
                                                  QtWidgets.QMessageBox.Yes | QtWidgets.QMessageBox.No)
             if sel == QtWidgets.QMessageBox.Yes:
                 try:
@@ -653,7 +712,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 except (OSError, IOError) as ex:
                     QtWidgets.QMessageBox.critical(
                         self, self.tr("Problem while saving flight track to FTML:"),
-                        self.tr("ERROR: {} {}".format(type(ex), ex)))
+                        self.tr(f"ERROR: {type(ex)} {ex}"))
         else:
             self.save_flight_track_as()
 
@@ -662,7 +721,7 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         """
         default_filename = os.path.join(self.last_save_directory, self.active_flight_track.name + ".ftml")
         filename = get_save_filename(
-            self, "Save Flight Track", default_filename, "Flight Track (*.ftml)", pickertag="filepicker_flightrack")
+            self, "Save Flight Track", default_filename, "Flight Track (*.ftml)", pickertag="filepicker_default")
         logging.debug("filename : '%s'", filename)
         if filename:
             self.last_save_directory = fs.path.dirname(filename)
@@ -672,13 +731,13 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
                 except (OSError, IOError) as ex:
                     QtWidgets.QMessageBox.critical(
                         self, self.tr("Problem while saving flight track to FTML:"),
-                        self.tr("ERROR: {} {}".format(type(ex), ex)))
+                        self.tr(f"ERROR: {type(ex)} {ex}"))
                 for idx in range(self.listFlightTracks.count()):
                     if self.listFlightTracks.item(idx).flighttrack_model == self.active_flight_track:
                         self.listFlightTracks.item(idx).setText(self.active_flight_track.name)
             else:
                 QtWidgets.QMessageBox.warning(self, "Save flight track",
-                                              "File extension is not '.ftml'!\n{:}".format(filename))
+                                              f"File extension is not '.ftml'!\n{filename:}")
 
     def activate_flight_track(self, item):
         """Set the currently selected flight track to be the active one, i.e.
@@ -707,6 +766,13 @@ class MSSMainWindow(QtWidgets.QMainWindow, ui.Ui_MSSMainWindow):
         dlg.setModal(True)
         dlg.exec_()
 
+    def show_shortcuts(self):
+        """Show the shortcuts dialog to the user.
+        """
+        dlg = MSS_ShortcutsDialog()
+        dlg.setModal(True)
+        dlg.exec_()
+
     def status(self):
         if constants.CACHED_CONFIG_FILE is None:
             return ("Status : System Configuration")
@@ -723,7 +789,7 @@ def main():
         prefix = ""
     app_prefix = prefix
     if prefix:
-        app_prefix = "-{}".format(prefix)
+        app_prefix = f"-{prefix}"
     icon_hash = hashlib.md5('.'.join([__version__, app_prefix]).encode('utf-8')).hexdigest()
 
     parser = argparse.ArgumentParser()
@@ -762,7 +828,7 @@ def main():
             if not os.path.exists(dirname):
                 os.makedirs(dirname)
             if prefix:
-                prefix = "({})".format(prefix)
+                prefix = f"({prefix})"
             desktop = desktop.format(prefix,
                                      os.path.join(sys.prefix, "bin", "mss"),
                                      icon_destination)
@@ -789,6 +855,7 @@ def main():
     application = QtWidgets.QApplication(sys.argv)
     application.setWindowIcon(QtGui.QIcon(icons('128x128')))
     application.setApplicationDisplayName("MSS")
+    application.setAttribute(QtCore.Qt.AA_DisableWindowContextHelpButton)
     mainwindow = MSSMainWindow()
     mainwindow.create_new_flight_track()
     mainwindow.show()
